#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# aiodocker documentation build configuration file, created by
# sphinx-quickstart on Sat Jul 15 11:34:21 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

import os
import sys
import codecs
import re

_docs_path = os.path.dirname(__file__)
_version_path = os.path.abspath(os.path.join(_docs_path,
                                             '..', 'aiodocker', '__init__.py'))
with codecs.open(_version_path, 'r', 'latin1') as fp:
    try:
        _version_info = re.search(r"^__version__ = \""
                                  r"(?P<major>\d+)"
                                  r"\.(?P<minor>\d+)"
                                  r"\.(?P<patch>\d+)"
                                  r"(?P<tag>.*)?\"$",
                                  fp.read(), re.M).groupdict()
    except IndexError:
        raise RuntimeError('Unable to determine version.')

_root_path = os.path.abspath(os.path.join(_docs_path, '..'))
sys.path.insert(0, _root_path)


# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.intersphinx',
              'sphinx.ext.viewcode',
              'alabaster',
              'sphinxcontrib.asyncio',
              'sphinx.ext.autodoc',
              'sphinx.ext.napoleon',
              'sphinx_autodoc_typehints']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'aiodocker'
copyright = '2017-2018, Paul Tagliamonte, Joongi Kim and aiodocker team'
author = 'Paul Tagliamonte, Joongi Kim, aiodocker team'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = '{major}.{minor}'.format(**_version_info)
# The full version, including alpha/beta/rc tags.
release = '{major}.{minor}.{patch}-{tag}'.format(**_version_info)

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False

# The default language to highlight source code in.
highlight_language = 'python3'

# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'alabaster'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#

html_theme_options = {
#    'logo': 'aiojobs-icon-128x128.png',
    'description': 'Python Docker API client based on asyncio and aiohttp',
    'github_user': 'aio-libs',
    'github_repo': 'aiodocker',
    'github_button': True,
    'github_type': 'star',
    'github_banner': True,
    'pre_bg': '#FFF6E5',
    'note_bg': '#E5ECD1',
    'note_border': '#BFCF8C',
    'body_text': '#482C0A',
    'sidebar_text': '#49443E',
    'sidebar_header': '#4B4032',
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars


html_sidebars = {
    '**': [
        'about.html', 'navigation.html', 'searchbox.html',
    ]
}

# html_sidebars = {
#    '**': [
#        'about.html',
#        'navigation.html',
#         # needs 'show_related': True theme option to display
#        'relations.html',
#        'searchbox.html',
#        'donate.html',
#    ]
# }


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'aiodockerdoc'


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'aiodocker.tex', 'aiodocker Documentation',
     'Paul Tagliamonte, Joongi Kim', 'manual'),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'aiodocker', 'aiodocker Documentation',
     [author], 1)
]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'aiodocker', 'aiodocker Documentation',
     author, 'aiodocker', 'One line description of project.',
     'Miscellaneous'),
]


# Example configuration for intersphinx: refer to the Python standard
# library.
intersphinx_mapping = {
    'https://docs.python.org/': None,
    'aiohttp': ('https://aiohttp.readthedocs.io/en/stable/', None),
}
